==> estateplat-common-1.2.4-20190516.095329-160-sources.jar: cn/gtmap/estateplat/model/server/core/BdcSfxx.java <==
package cn.gtmap.estateplat.model.server.core;


import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * 不动产收费单信息
 *
 * @author <a href="mailto: lijian@gtmap.cn">lj</a>
 * @version 1.0 15-12-5
 */
@Table(name = "BDC_SFXX")
public class BdcSfxx implements Serializable, BdcProid {
    @Id
    private String sfxxid;//收费 信息id

    private String wiid;//工作流ID

    private String proid;//项目id

    private Date sjrq;//收缴日期

    private Double hj;//合计

    private String bz;//备注

    private String sfdcsr;//收费单初审人

    private String sfdfsr;//收费单复审人

    private Double hsje;//核收金额

    private String sfdw;//收费机构

    private String sfzt;//收费状态 0：未收费1：已收费2：部分缴费

    private String jkr;//交款人

    private String jkrzh;//缴款人账号

    private String jkrkhyh;//缴款人开户银行

    private String skr;//收款人

    private String skrzh;//收款人账号

    private String skrkhyh;//收款人开户银行

    private String sfdwdm;//收费单位代码

    private String sfztczr;//收费状态操作人

    private Date sfztczrq;//收费状态操作日期

    private String fph;//发票号

    private Double qlrsfhj;//权利人收费合计

    private Double ywrsfhj;//义务人收费合计

    private String cztxmbh;//财政条形码编号
    private String jkfs;//缴款方式
    private String zsfs;//征收方式
    private String zphm;//支票号码
    private String qlrlx;//权利人类型
    private String cwfph;//财务发票号
    private Double zdzhmj;//宗地宗海面积

    public String getSfxxid() {
        return sfxxid;
    }

    public void setSfxxid(String sfxxid) {
        this.sfxxid = sfxxid;
    }

    public String getWiid() {
        return wiid;
    }

    public void setWiid(String wiid) {
        this.wiid = wiid;
    }

    public Double getHsje() {
        return hsje;
    }

    public void setHsje(Double hsje) {
        this.hsje = hsje;
    }

    public String getSfdw() {
        return sfdw;
    }

    public void setSfdw(String sfdw) {
        this.sfdw = sfdw;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public Date getSjrq() {
        return sjrq;
    }

    public void setSjrq(Date sjrq) {
        this.sjrq = sjrq;
    }

    public Double getHj() {
        return hj;
    }

    public void setHj(Double hj) {
        this.hj = hj;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getSfdcsr() {
        return sfdcsr;
    }

    public void setSfdcsr(String sfdcsr) {
        this.sfdcsr = sfdcsr;
    }

    public String getSfdfsr() {
        return sfdfsr;
    }

    public void setSfdfsr(String sfdfsr) {
        this.sfdfsr = sfdfsr;
    }

    public String getSfzt() {
        return sfzt;
    }

    public void setSfzt(String sfzt) {
        this.sfzt = sfzt;
    }

    public String getJkr() {
        return jkr;
    }

    public void setJkr(String jkr) {
        this.jkr = jkr;
    }

    public String getJkrzh() {
        return jkrzh;
    }

    public void setJkrzh(String jkrzh) {
        this.jkrzh = jkrzh;
    }

    public String getJkrkhyh() {
        return jkrkhyh;
    }

    public void setJkrkhyh(String jkrkhyh) {
        this.jkrkhyh = jkrkhyh;
    }

    public String getSkr() {
        return skr;
    }

    public void setSkr(String skr) {
        this.skr = skr;
    }

    public String getSkrzh() {
        return skrzh;
    }

    public void setSkrzh(String skrzh) {
        this.skrzh = skrzh;
    }

    public String getSkrkhyh() {
        return skrkhyh;
    }

    public void setSkrkhyh(String skrkhyh) {
        this.skrkhyh = skrkhyh;
    }

    public String getSfdwdm() {
        return sfdwdm;
    }

    public void setSfdwdm(String sfdwdm) {
        this.sfdwdm = sfdwdm;
    }

    public String getSfztczr() {
        return sfztczr;
    }

    public void setSfztczr(String sfztczr) {
        this.sfztczr = sfztczr;
    }

    public Date getSfztczrq() {
        return sfztczrq;
    }

    public void setSfztczrq(Date sfztczrq) {
        this.sfztczrq = sfztczrq;
    }

    public String getFph() {
        return fph;
    }

    public void setFph(String fph) {
        this.fph = fph;
    }

    public Double getQlrsfhj() {
        return qlrsfhj;
    }

    public void setQlrsfhj(Double qlrsfhj) {
        this.qlrsfhj = qlrsfhj;
    }

    public Double getYwrsfhj() {
        return ywrsfhj;
    }

    public void setYwrsfhj(Double ywrsfhj) {
        this.ywrsfhj = ywrsfhj;
    }

    public String getCztxmbh() {
        return cztxmbh;
    }

    public void setCztxmbh(String cztxmbh) {
        this.cztxmbh = cztxmbh;
    }

    public String getJkfs() {
        return jkfs;
    }

    public void setJkfs(String jkfs) {
        this.jkfs = jkfs;
    }

    public String getZsfs() {
        return zsfs;
    }

    public void setZsfs(String zsfs) {
        this.zsfs = zsfs;
    }

    public String getZphm() {
        return zphm;
    }

    public void setZphm(String zphm) {
        this.zphm = zphm;
    }

    public String getQlrlx() {
        return qlrlx;
    }

    public void setQlrlx(String qlrlx) {
        this.qlrlx = qlrlx;
    }

    public String getCwfph() {
        return cwfph;
    }

    public void setCwfph(String cwfph) {
        this.cwfph = cwfph;
    }

    public Double getZdzhmj() {
        return zdzhmj;
    }

    public void setZdzhmj(Double zdzhmj) {
        this.zdzhmj = zdzhmj;
    }
}

==> estateplat-common-1.2.4-20200410.015356-315-sources.jar: cn/gtmap/estateplat/model/server/core/BdcSfxx.java <==
package cn.gtmap.estateplat.model.server.core;


import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * 不动产收费单信息
 *
 * @author <a href="mailto: lijian@gtmap.cn">lj</a>
 * @version 1.0 15-12-5
 */
@Table(name = "BDC_SFXX")
public class BdcSfxx implements Serializable, BdcProid {
    @Id
    private String sfxxid;//收费 信息id

    private String wiid;//工作流ID

    private String proid;//项目id

    private Date sjrq;//收缴日期

    private Double hj;//合计

    private String bz;//备注

    private String sfdcsr;//收费单初审人

    private String sfdfsr;//收费单复审人

    private Double hsje;//核收金额

    private String sfdw;//收费机构

    private String sfzt;//收费状态 0：未收费1：已收费2：部分缴费

    private String jkr;//交款人

    private String jkrzh;//缴款人账号

    private String jkrkhyh;//缴款人开户银行

    private String skr;//收款人

    private String skrzh;//收款人账号

    private String skrkhyh;//收款人开户银行

    private String sfdwdm;//收费单位代码

    private String sfztczr;//收费状态操作人

    private Date sfztczrq;//收费状态操作日期

    private String fph;//发票号

    private Double qlrsfhj;//权利人收费合计

    private Double ywrsfhj;//义务人收费合计

    private String cztxmbh;//财政条形码编号
    private String jkfs;//缴款方式
    private String zsfs;//征收方式
    private String zphm;//支票号码
    private String qlrlx;//权利人类型
    private String cwfph;//财务发票号
    private Double zdzhmj;//宗地宗海面积
    private String sfzwxqy;//是否中微小企业 1：是 0：否

    public String getSfxxid() {
        return sfxxid;
    }

    public void setSfxxid(String sfxxid) {
        this.sfxxid = sfxxid;
    }

    public String getWiid() {
        return wiid;
    }

    public void setWiid(String wiid) {
        this.wiid = wiid;
    }

    public Double getHsje() {
        return hsje;
    }

    public void setHsje(Double hsje) {
        this.hsje = hsje;
    }

    public String getSfdw() {
        return sfdw;
    }

    public void setSfdw(String sfdw) {
        this.sfdw = sfdw;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public Date getSjrq() {
        return sjrq;
    }

    public void setSjrq(Date sjrq) {
        this.sjrq = sjrq;
    }

    public Double getHj() {
        return hj;
    }

    public void setHj(Double hj) {
        this.hj = hj;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getSfdcsr() {
        return sfdcsr;
    }

    public void setSfdcsr(String sfdcsr) {
        this.sfdcsr = sfdcsr;
    }

    public String getSfdfsr() {
        return sfdfsr;
    }

    public void setSfdfsr(String sfdfsr) {
        this.sfdfsr = sfdfsr;
    }

    public String getSfzt() {
        return sfzt;
    }

    public void setSfzt(String sfzt) {
        this.sfzt = sfzt;
    }

    public String getJkr() {
        return jkr;
    }

    public void setJkr(String jkr) {
        this.jkr = jkr;
    }

    public String getJkrzh() {
        return jkrzh;
    }

    public void setJkrzh(String jkrzh) {
        this.jkrzh = jkrzh;
    }

    public String getJkrkhyh() {
        return jkrkhyh;
    }

    public void setJkrkhyh(String jkrkhyh) {
        this.jkrkhyh = jkrkhyh;
    }

    public String getSkr() {
        return skr;
    }

    public void setSkr(String skr) {
        this.skr = skr;
    }

    public String getSkrzh() {
        return skrzh;
    }

    public void setSkrzh(String skrzh) {
        this.skrzh = skrzh;
    }

    public String getSkrkhyh() {
        return skrkhyh;
    }

    public void setSkrkhyh(String skrkhyh) {
        this.skrkhyh = skrkhyh;
    }

    public String getSfdwdm() {
        return sfdwdm;
    }

    public void setSfdwdm(String sfdwdm) {
        this.sfdwdm = sfdwdm;
    }

    public String getSfztczr() {
        return sfztczr;
    }

    public void setSfztczr(String sfztczr) {
        this.sfztczr = sfztczr;
    }

    public Date getSfztczrq() {
        return sfztczrq;
    }

    public void setSfztczrq(Date sfztczrq) {
        this.sfztczrq = sfztczrq;
    }

    public String getFph() {
        return fph;
    }

    public void setFph(String fph) {
        this.fph = fph;
    }

    public Double getQlrsfhj() {
        return qlrsfhj;
    }

    public void setQlrsfhj(Double qlrsfhj) {
        this.qlrsfhj = qlrsfhj;
    }

    public Double getYwrsfhj() {
        return ywrsfhj;
    }

    public void setYwrsfhj(Double ywrsfhj) {
        this.ywrsfhj = ywrsfhj;
    }

    public String getCztxmbh() {
        return cztxmbh;
    }

    public void setCztxmbh(String cztxmbh) {
        this.cztxmbh = cztxmbh;
    }

    public String getJkfs() {
        return jkfs;
    }

    public void setJkfs(String jkfs) {
        this.jkfs = jkfs;
    }

    public String getZsfs() {
        return zsfs;
    }

    public void setZsfs(String zsfs) {
        this.zsfs = zsfs;
    }

    public String getZphm() {
        return zphm;
    }

    public void setZphm(String zphm) {
        this.zphm = zphm;
    }

    public String getQlrlx() {
        return qlrlx;
    }

    public void setQlrlx(String qlrlx) {
        this.qlrlx = qlrlx;
    }

    public String getCwfph() {
        return cwfph;
    }

    public void setCwfph(String cwfph) {
        this.cwfph = cwfph;
    }

    public Double getZdzhmj() {
        return zdzhmj;
    }

    public void setZdzhmj(Double zdzhmj) {
        this.zdzhmj = zdzhmj;
    }

    public String getSfzwxqy() {
        return sfzwxqy;
    }

    public void setSfzwxqy(String sfzwxqy) {
        this.sfzwxqy = sfzwxqy;
    }
}
